# <img src="https://github.com/pip-services/pip-services/raw/master/design/Logo.png" alt="Pip.Services Logo" style="max-width:30%"> <br/> Communication framework for Python

This framework is a part of [Pip.Services](https://github.com/pip-services/pip-services) project.
It provides synchronous and asynchronous communication components 

- **Messaging** - asynchronous message queues
- **Rest** - RESTful services and clients

Quick Links:

* [Downloads](https://github.com/pip-services/pip-services-net-python/blob/master/doc/Downloads.md)
* [API Reference](http://htmlpreview.github.io/?https://github.com/pip-services/pip-services-net-python/blob/master/doc/api/index.html)
* [Building and Testing](https://github.com/pip-services/pip-services-net-python/blob/master/doc/Development.md)
* [Contributing](https://github.com/pip-services/pip-services-net-python/blob/master/doc/Development.md/#contrib)

## Acknowledgements

The Python version of Pip.Services is created and maintained by **Sergey Seroukhov**
